BarGraphItem — pyqtgraph 0.11.0rc0 documentation

# BarGraphItem

class `pyqtgraph.` `BarGraphItem`(**opts)
  `__init__`(**opts)

    Valid keyword options are: x, x0, x1, y, y0, y1, width, height, pen, brush

    x specifies the x-position of the center of the bar. x0, x1 specify left and right edges of the bar, respectively. width specifies distance from x0 to x1. You may specify any combination:

    > x, width x0, width x1, width x0, x1

    Likewise y, y0, y1, and height. If only height is specified, then y0 will be set to 0

    Example uses:

    > BarGraphItem(x=range(5), height=[1,5,2,4,3], width=0.5)

  `boundingRect`(self) → PySide2.QtCore.QRectF
  `paint`(self, painter: PySide2.QtGui.QPainter, option: PySide2.QtWidgets.QStyleOptionGraphicsItem, widget: typing.Union[PySide2.QtWidgets.QWidget, NoneType] = None)
  `shape`(self) → PySide2.QtGui.QPainterPath